@echo OFF
     set CMD_NAME=CBUT1AE1
rem  * *******************************************************************
rem  *       This Job Script is provided by SimoTime Technologies        *
rem  *           (C) Copyright 1987-2020 All Rights Reserved             *
rem  *             Web Site URL:   http://www.simotime.com               *
rem  *                   e-mail:   helpdesk@simotime.com                 *
rem  * *******************************************************************
rem  * This procedure will create a file containing a list of all the
rem  * COBOL (i.e. filename.cbl) programs. This list will then be used to
rem  * compile all the programs in the COBOLUT1 Folder (or Library).
rem  *
rem  * This procedure calls the following Windows Command Files.
rem  * 1. ENV1BASE.cmd - provides a single point for setting commonly
rem  *                   used environment variables.
rem  * 2. SIMONOTE.cmd - provides a consistent process for displaying
rem  *                   messages to the screen and writing to a journal
rem  *                   or log file.
rem  * 3. ZCBL2GNT.cmd - this will do the actual compile of the specified
rem  *                   program.
rem  *
rem  * Note: To specify the directory to be used for the IDY files use
rem  *       the COBIDY Compiler Directive and set the COBIDY environment
rem  *       variable.
rem  * *******************************************************************
     setlocal
     call ..\ENV1BASE
rem  *
     call SIMONOTE "*******************************************************************************%CMD_NAME%.cmd"
     call SIMONOTE "* Starting JobName %CMD_NAME%.cmd"
     call SIMONOTE "* Job_Step 01 of 03, Preparing the System and Job Environments"
rem  *
rem  * Set the environment variable to use the MiFoAsc.DIR directives file
rem  * as the default.
     set DIRSLIB1=%BaseLib1%\DIRS\ASC1
     set zDIRS=%BaseLib1%\DIRS\ASC1\ENTCOBOLAscCBLBAT.DIR
rem  * The following two statements will set the environment variables to
rem  * a "Y" for Yes or "N" for No. A "Y" will cause the function to be
rem  * performed by the called procedure. An "N" value will not perform the
rem  * function.
     set EraseAfter=N
     set TransferGNT=N
rem  *
rem  * Read the file containing a list of program names and pass the contents
rem  * of each record to the command file that does the actual compile.
rem  * Each record in the file contains an eight character program name.
     set AOK_Count=0
     set NOK_Count=0
     set SLIB1=COBOLUT1
     set TLIB1=HOLD\UT1A
rem  *
     call SIMONOTE "* --------------------------------------------------------------------------- *"
     call SIMONOTE "* Job_Step 02 of 03, Compile the COBOL Programs..."
     set MBR_LIST=%BASELIB1%\ADM1\CNTL\SIMOTIME.ADM1.COBOLUT1.lst
     call SIMONOTE "* MBR_LIST is %MBR_LIST% "
     dir /on /b /a-d %BaseLib1%\%SLIB1%\*.cbl>%MBR_LIST%
     for /F "eol=; tokens=1,2* delims=." %%i in (%MBR_LIST%) do CALL zCBL2GNT %%i %SLIB1% %TLIB1%
rem  *
     call SIMONOTE "* Conclude MIFOSYS1..... %MIFOSYS1% "
     call SIMONOTE "* Conclude COBCPY....... %COBCPY% "
     call SIMONOTE "* Conclude COBIDY....... %COBIDY% "
rem  *
:EOJTAG
     call SIMONOTE "* --------------------------------------------------------------------------- *"
     call SIMONOTE "* Job_Step 03 of 03, End of Job Processing..."
     call SIMONOTE "* AOKcount Compile Count for AOK is %AOK_Count% "
     call SIMONOTE "* NOKcount Compile Count for NOK is %NOK_Count% "
     if not "%NOK_Count%" == "0" goto EOJNOK
:EOJAOK
     call SIMONOTE "* Finished JobName %CMD_NAME%.CMD "
     goto END
:EOJNOK 
     call SIMONOTE "* ABENDING JobName %CMD_NAME%.CMD "
:END
     if not "%SimoGENS%" == "BATCH" pause
     endlocal

